I also discovered that testing is significantly impacted by prior run caching of memory maps by the OS. This was affecting my interpretation of smaller changes, which didn't make sense. For example, on confirmation run to block 300k is 5-10x faster when a previous run has mapped the same memory (even after process termination). So it's hard to separate out the true savings here without a bunch more work.